# Orbital Insight Platform API (OI Papi)

PAPI (Platform API) is the gateway to Orbital Insight's Terra platform. PAPI provides a single, unified API for developers to build geospatial analytics solutions tailed to their specific domains. PAPI provides both gRPC and HTTP Rest endpoints.

For more information about PAPI endpoints please refer to the [API documentation](https://sphinx.core3.orbitalinsight.io/oi_papi/latest/api-docs/).

If you are developer of PAPI itself, please refer to the [Local Setup and Testing](docs/local_setup_and_testing.md) document to get started.
